"""A complete pastebin.com API wrapper for Python

.. moduleauthor:: Ferdinand Silva <ferdinandsilva@ferdinandsilva.com>

"""
from pastebin import PastebinPython

__version__ = "1.1"
__app_name__ = "pastebin_python"
__description__ = "A complete pastebin.com API wrapper for Python"
__author__ = "Ferdinand Silva"
__author_email__ = "ferdinandsilva@ferdinandsilva.com"
__app_url__ = "http://ferdinandsilva.com"
__download_url__ = "https://github.com/six519/PastebinPython"